@@ -209,6 +209,9 @@ class Environment(NamedTuple):
     cc: str
     cxx: str
     linker: str
+    base_cflags: List[str]
+    base_cxxflags: List[str]
+    base_ldflags: List[str]
     cflags: List[str]
     ldflags: List[str]
     make: str
@@ -262,8 +265,11 @@ def init_env(debug=False, sanitize=False, compiling_for='native'):
         cflags = shlex.split(cflags) + ['-fPIC']
         ldflags = os.environ.get('OVERRIDE_LDFLAGS', '-Wall')
         ldflags = shlex.split(ldflags)
-        cflags += shlex.split(os.environ.get('CFLAGS', ''))
-        ldflags += shlex.split(os.environ.get('LDFLAGS', ''))
+        base_cflags = shlex.split(os.environ.get('CFLAGS', ''))
+        base_cxxflags = shlex.split(os.environ.get('CXXFLAGS', ''))
+        base_ldflags = shlex.split(os.environ.get('LDFLAGS', ''))
+        cflags += base_cflags
+        ldflags += base_ldflags
         cflags += ['-fvisibility=hidden']
         if sanitize:
             cflags.append('-fsanitize-address')
@@ -272,6 +278,7 @@ def init_env(debug=False, sanitize=False, compiling_for='native'):
     if islinux:
         cflags.append('-pthread')
         if sys.stdout.isatty():
+            base_cflags.append('-fdiagnostics-color=always')
             cflags.append('-fdiagnostics-color=always')
         ldflags.append('-shared')
 
@@ -309,16 +316,17 @@ def init_env(debug=False, sanitize=False, compiling_for='native'):
         cc = cxx = win_cc
         linker = win_ld
         cflags, ldflags = basic_windows_flags(debug)
+        base_cflags, base_cxxflags, base_ldflags = [], [], []
         if compiling_for == 'windows':
             cc = cxx = 'clang-cl'
             linker = 'lld-link'
-            splat = '.build-cache/xwin/splat'
+            splat = '.build-cache/xwin/root'
             cflags.append('-fcolor-diagnostics')
             cflags.append('-fansi-escape-codes')
             for I in 'sdk/include/um sdk/include/cppwinrt sdk/include/shared sdk/include/ucrt crt/include'.split():
                 cflags.append('/external:I')
                 cflags.append(f'{splat}/{I}')
-            for L in 'sdk/lib/um/x86_64 crt/lib/x86_64 sdk/lib/ucrt/x86_64'.split():
+            for L in 'sdk/lib/um crt/lib sdk/lib/ucrt'.split():
                 ldflags.append(f'/libpath:{splat}/{L}')
         else:
             for p in win_inc:
@@ -347,6 +355,7 @@ def init_env(debug=False, sanitize=False, compiling_for='native'):
             ldflags.append('/LIBPATH:'+os.path.join(sysconfig.get_config_var('prefix'), 'libs'))
     return Environment(
         platform_name=platform_name, dest_ext=dest_ext, std_prefix=std_prefix,
+        base_cflags=base_cflags, base_cxxflags=base_cxxflags, base_ldflags=base_ldflags,
         cc=cc, cxx=cxx, cflags=cflags, ldflags=ldflags, linker=linker, make=NMAKE if iswindows else 'make', lib_prefix=lib_prefix,
         obj_suffix=obj_suffix, cc_input_c_flag=cc_input_c_flag, cc_input_cpp_flag=cc_input_cpp_flag, cc_output_flag=cc_output_flag,
         internal_inc_prefix=internal_inc_prefix, external_inc_prefix=external_inc_prefix, libdir_prefix=libdir_prefix, lib_suffix=lib_suffix)
@@ -421,7 +430,7 @@ class Build(Command):
         self.compiling_for = 'native'
         if islinux and opts.cross_compile_extensions == 'windows':
             self.compiling_for = 'windows'
-            if not os.path.exists('.build-cache/xwin/splat'):
+            if not os.path.exists('.build-cache/xwin/root'):
                 subprocess.check_call([sys.executable, 'setup.py', 'xwin'])
         self.env = init_env(debug=opts.debug)
         self.windows_cross_env = init_env(debug=opts.debug, compiling_for='windows')
@@ -539,8 +548,6 @@ class Build(Command):
 
             if ext.needs_c_std and not env.std_prefix.startswith('/'):
                 cflags.append(env.std_prefix + 'c' + ext.needs_c_std)
-            if env is self.windows_cross_env:
-                cflags.append('-Wno-deprecated-experimental-coroutine')
 
             cmd = [compiler] + env.cflags + cflags + ext.cflags + einc + sinc + oinc
             return CompileCommand(cmd, src, obj)
@@ -679,6 +686,16 @@ project-factory = "pyqtbuild:PyQtProject"
 sip-files-dir = "."
 {abi_version}
 
+[tool.sip.builder]
+qmake-settings = [
+    'QMAKE_CC = {self.env.cc}',
+    'QMAKE_CXX = {self.env.cxx}',
+    'QMAKE_LINK = {self.env.linker or self.env.cxx}',
+    'QMAKE_CFLAGS += {shlex.join(self.env.base_cflags)}',
+    'QMAKE_CXXFLAGS += {shlex.join(self.env.base_cxxflags)}',
+    'QMAKE_LFLAGS += {shlex.join(self.env.base_ldflags)}',
+]
+
 [tool.sip.bindings.{ext.name}]
 headers = {ext.headers}
 sources = {ext.sources}
