@@ -301,6 +301,8 @@ class ImageDropMixin:  # {{{
             self.set_pixmap(pmap)
             self.cover_changed.emit(
                     pixmap_to_data(pmap, format='PNG'))
+            return True
+        return False
 # }}}
 
 
@@ -323,6 +325,7 @@ class ImageView(QWidget, ImageDropMixin):
 
     BORDER_WIDTH = 1
     cover_changed = pyqtSignal(object)
+    draw_empty_border = False
 
     def __init__(self, parent=None, show_size_pref_name=None, default_show_size=False):
         QWidget.__init__(self, parent)
@@ -366,7 +369,15 @@ class ImageView(QWidget, ImageDropMixin):
     def paintEvent(self, event):
         QWidget.paintEvent(self, event)
         pmap = self._pixmap
+        p = QPainter(self)
+        p.setRenderHints(QPainter.RenderHint.Antialiasing | QPainter.RenderHint.SmoothPixmapTransform)
         if pmap.isNull():
+            if self.draw_empty_border:
+                pen = QPen()
+                pen.setWidth(self.BORDER_WIDTH)
+                p.setPen(pen)
+                p.drawRect(self.rect())
+                p.end()
             return
         w, h = pmap.width(), pmap.height()
         ow, oh = w, h
@@ -379,8 +390,6 @@ class ImageView(QWidget, ImageDropMixin):
         x = int(abs(cw - w)/2)
         y = int(abs(ch - h)/2)
         target = QRect(x, y, w, h)
-        p = QPainter(self)
-        p.setRenderHints(QPainter.RenderHint.Antialiasing | QPainter.RenderHint.SmoothPixmapTransform)
         p.drawPixmap(target, pmap)
         if self.draw_border:
             pen = QPen()
@@ -389,7 +398,6 @@ class ImageView(QWidget, ImageDropMixin):
             p.drawRect(target)
         if self.show_size:
             draw_size(p, target, ow, oh)
-        p.end()
 # }}}
 
 
